@@ -3,7 +3,7 @@ from __future__ import annotations
 import pytest
 
 from dask.array import from_array
-from dask.base import collections_to_dsk
+from dask.base import collections_to_expr
 
 pytest.importorskip("numpy")
 
@@ -125,8 +125,7 @@ def test_overlap_internal_asymmetric_small():
 def test_trim_internal():
     d = da.ones((40, 60), chunks=(10, 10))
     e = trim_internal(d, axes={0: 1, 1: 2}, boundary="reflect")
-    assert any("_overlap_trim_info" in k[0] for k in dict(e.dask))
-
+    assert len(collections_to_expr([e]).__dask_graph__()) == 24
     assert e.chunks == ((8, 8, 8, 8), (6, 6, 6, 6, 6, 6))
 
 
@@ -568,6 +567,18 @@ def test_map_overlap_deprecated_signature():
         assert y.shape == (3,)
 
 
+def test_map_overlap_trim_false_chunking():
+    a = np.arange(100)
+    c = da.from_array(a, chunks=15)
+
+    def f(x):
+        return x[20:-20]
+
+    d = da.map_overlap(f, c, depth={0: 20}, boundary=0, trim=False)
+    print(d.shape)
+    print(d.compute().shape)
+
+
 def test_nearest_overlap():
     a = np.arange(144).reshape(12, 12).astype(float)
 
@@ -949,5 +960,5 @@ def test_overlap_not_blowing_up_graph():
         dims=["x", "y", "z", "year"],
     )
     result = arr.rolling(dim={"year": 11}, center=True).construct("window_dim")
-    dc = collections_to_dsk([result.data])
+    dc = collections_to_expr([result.data]).__dask_graph__()
     assert len(dc) <= 1651  # previously 3000
