@@ -415,6 +415,7 @@ class RepartitionFreq(Repartition):
 
 
 class RepartitionSize(Repartition):
+
     @functools.cached_property
     def _size(self):
         size = self.operand("partition_size")
@@ -422,14 +423,18 @@ class RepartitionSize(Repartition):
             size = parse_bytes(size)
         return int(size)
 
+    @functools.cached_property
+    def _mem_usage(self):
+        return _get_mem_usages(self.frame)
+
     @functools.cached_property
     def _nsplits(self):
-        return 1 + _get_mem_usages(self.frame) // self._size
+        return 1 + self._mem_usage // self._size
 
     @functools.cached_property
     def _partition_boundaries(self):
         nsplits = self._nsplits
-        mem_usages = _get_mem_usages(self.frame)
+        mem_usages = self._mem_usage
 
         if np.any(nsplits > 1):
             split_mem_usages = []
@@ -449,6 +454,11 @@ class RepartitionSize(Repartition):
             return (None,) * len(self._partition_boundaries)
         return (self.frame.divisions[i] for i in self._partition_boundaries)
 
+    def _lower(self):
+        # populate cache
+        self._mem_usage  # noqa
+        return super()._lower()
+
     def _layer(self) -> dict:
         df = self.frame
         dsk: dict[tuple, Any] = {}
